@@ -126,6 +126,8 @@ Change log
 ----------
 
 * 0.3:
+    * 0.3.1 (*2013-03-17*):
+        Fixed setup bug (in Manifest.in)
     * 0.3.0 (*2013-03-17*):
         Implemented cookie middleware
 * 0.2:
@@ -142,4 +144,4 @@ Change log
         First version.
 """
 
-__version__ = "0.3.0"
\ No newline at end of file
+__version__ = "0.3.1"
\ No newline at end of file
